<?php

/**
 * @file
 * Provides field view routines.
 *
 * @author Jim Berry ("solotandem", http://drupal.org/user/240748)
 */

/**
 * Implements hook_field_formatter_view().
 *
 * @see image_field_formatter_view()
 */
function _remote_content_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  $element = array();

  // Check if the formatter involves a link.
  if ($display['settings']['image_link'] == 'content') {
    $uri = entity_uri($entity_type, $entity);
  }
  elseif ($display['settings']['image_link'] == 'file') {
    $link_file = TRUE;
  }

  foreach ($items as $delta => $item) {
    if (isset($link_file)) {
      $item['uri'] = remote_content_scheme_mark($item['uri']);
      $uri = array(
        'path' => file_create_url($item['uri']),
        'options' => array(),
      );
    }
    $element[$delta] = array(
      '#theme' => 'remote_image_formatter',
      '#item' => $item,
      '#image_style' => $display['settings']['image_style'],
      '#path' => isset($uri) ? $uri : '',
    );
  }

  return $element;
}

/**
 * Returns HTML for a remote image field formatter.
 *
 * @param $variables
 *   An associative array containing:
 *   - item: Associative array of image data, which may include "uri", "alt",
 *     "width", "height", "title" and "attributes".
 *   - image_style: An optional image style.
 *   - path: An array containing the link 'path' and link 'options'.
 *
 * @see theme_image_formatter()
 * @ingroup themeable
 */
function theme_remote_image_formatter($variables) {
  $variables['item']['uri'] = remote_content_scheme_mark($variables['item']['uri']);
  return theme_image_formatter($variables);
}

/**
 * Marks the stream wrapper scheme for later modification.
 *
 * @param string $uri
 *   File uri in stream wrapper notation.
 *
 * @return string
 *   Modified file uri.
 *
 * @see _remote_content_file_url_alter()
 */
function remote_content_scheme_mark($uri) {
  if (remote_content_state_check()) {
    $scheme = file_uri_scheme($uri);
    if ($scheme) {
      // Mark the stream wrapper scheme for later modification.
      $uri = str_replace("$scheme://", "__remote_content__$scheme://", $uri);
    }
  }
  return $uri;
}

/**
 * Returns TRUE if conditions exist for remote file processing.
 */
function remote_content_state_check() {
  if (!RemoteNodeController::$remoteDatabase) {
    return FALSE;
  }
  if (!module_exists('portable_path')) {
    // @todo If remote_content module is not enabled on remote site, then these
    // filters will not be invoked on local site (due to query run in
    // filter_list_format() which will use the remote connection).
    // If we ignore this condition, then the filters can be enabled on remote.
    return FALSE;
  }
  return TRUE;
}

/**
 * Implements hook_file_url_alter().
 *
 * @see file_create_url()
 */
function _remote_content_file_url_alter(&$uri) {
  $scheme = file_uri_scheme($uri);
  if ($scheme && strpos($uri, '__remote_content__') === 0) {
    $uri = str_replace('__remote_content__', '', $uri);
    module_load_include('inc', 'portable_path', 'includes/filter');
    // Change to absolute URL to remote site.
    $uri = _portable_path_remote_stream_wrapper_process($uri, $filter = '', $format = '');
  }
}
