<?php

/**
 * @file
 * Contains the remote field handler.
 *
 * @author Jim Berry ("solotandem", http://drupal.org/user/240748)
 */

/**
 * A field that displays fieldapi fields.
 *
 * @ingroup views_field_handlers
 */
class remote_handler_field_field extends views_handler_field_field {

  /**
   * Load the entities for all fields that are about to be displayed.
   *
   * @param $values
   *   An array of all objects returned from the query.
   */
  function post_execute(&$values) {
    $options = $this->view->display_handler->options;
    if (!empty($options['remote_database'])) {
      // Set the active database connection to the remote database.
      RemoteNodeController::setRemoteDatabase($options['remote_database']);
    }
    parent::post_execute($values);
    if (!empty($options['remote_database'])) {
      // Restore the active database connection.
      RemoteNodeController::restoreDatabase();
    }
  }

  /**
   * Run before any fields are rendered.
   *
   * The body field is rendered during the post_execute phase.
   * A node link is created during the render phase.
   * All pre_render() routines are called before hook_views_pre_render().
   * Both routines are not needed to set the remote database connection.
   *
   * @param $values
   *   An array of all objects returned from the query.
   *
   * @see remote_content_views_pre_render()
   */
  function pre_render(&$values) {
    $options = $this->view->display_handler->options;
    if (!empty($options['remote_database'])) {
      // Set the active database connection to the remote database.
      RemoteNodeController::setRemoteDatabase($options['remote_database']);
      // Force path alias lookup from remote database.
      drupal_static_reset('drupal_lookup_path');
    }
    parent::pre_render($values);
  }
}
