<?php

/**
 * @file
 * Provides views items.
 *
 * @author Jim Berry ("solotandem", http://drupal.org/user/240748)
 */

/**
 * Implements hook_views_plugins().
 */
function remote_content_views_plugins() {
  $plugins = array(
    'display' => array(
      'remote_page' => array(
        'title' => t('Page (remote)'),
        'help' => t('Display the view as a page, with a URL and menu links.'),
        'handler' => 'remote_plugin_display_page',
        'theme' => 'views_view',
        'uses hook menu' => TRUE,
        'contextual links locations' => array('page'),
        'use ajax' => TRUE,
        'use pager' => TRUE,
        'use more' => TRUE,
        'accept attachments' => TRUE,
        'admin' => t('Page'),
        'help topic' => 'display-page',
      ),
      'remote_block' => array(
        'title' => t('Block (remote)'),
        'help' => t('Display the view as a block.'),
        'handler' => 'remote_plugin_display_block',
        'theme' => 'views_view',
        'uses hook block' => TRUE,
        'contextual links locations' => array('block'),
        'use ajax' => TRUE,
        'use pager' => TRUE,
        'use more' => TRUE,
        'accept attachments' => TRUE,
        'admin' => t('Block'),
        'help topic' => 'display-block',
      ),
      'remote_attachment' => array(
        'title' => t('Attachment (remote)'),
        'help' => t('Attachments added to other displays to achieve multiple views in the same view.'),
        'handler' => 'remote_plugin_display_attachment',
        'theme' => 'views_view',
        'contextual links locations' => array(),
        'use ajax' => TRUE,
        'use pager' => FALSE,
        'use more' => TRUE,
        'accept attachments' => FALSE,
        'help topic' => 'display-attachment',
      ),
    ),
    'query' => array(
      'remote_views_query' => array(
        'title' => t('Remote SQL Query'),
        'help' => t('Query will be generated and run using the Drupal database API on a remote database.'),
        'handler' => 'remote_plugin_query',
      ),
    ),
  );

  return $plugins;
}

/**
 * Implements hook_views_data_alter().
 */
function remote_content_views_data_alter(&$data) {
  $data['node']['table']['base']['query class'] = 'remote_views_query';
  $data['node']['title']['field']['handler'] = 'remote_handler_field_node';
  // @todo Also do above on node nid field?
  $data['node']['nid']['argument']['handler'] = 'remote_handler_argument_node_nid';
}

/**
 * Implements hook_field_views_data_alter().
 */
function remote_content_field_views_data_alter(&$data, $field, $module) {
  // @todo Limit the following to fields on remote content types.
  foreach ($data as $table => $info) {
    $column = $field['field_name'];
    if (isset($data[$table][$column]['field']['handler']) && $data[$table][$column]['field']['handler'] == 'views_handler_field_field') {
      $data[$table][$column]['field']['handler'] = 'remote_handler_field_field';
    }
    $old_column = 'revision_id';
    $column = $field['field_name'] . '-' . $old_column;
    if (isset($data[$table][$column]['field']['handler']) && $data[$table][$column]['field']['handler'] == 'views_handler_field_field') {
      $data[$table][$column]['field']['handler'] = 'remote_handler_field_field';
    }
  }
}

/**
 * Implements hook_views_pre_render().
 *
 * If the view uses fields, then this code will have already been executed in
 * the pre_render() routine of the remote field handler.
 *
 * @see remote_handler_field_field::pre_render()
 */
function remote_content_views_pre_render(&$view) {
  $options = $view->display_handler->options;
  if (!empty($options['remote_database'])) {
    if ($options['remote_database'] == RemoteNodeController::$remoteDatabase) {
      // The field handler was already called.
      // This code is here in case the view does not use fields.
      return;
    }
    // Set the active database connection to the remote database.
    RemoteNodeController::setRemoteDatabase($options['remote_database']);
    // Force path alias lookup from remote database.
    drupal_static_reset('drupal_lookup_path');
  }
}

/**
 * Implements hook_views_post_render().
 */
function remote_content_views_post_render(&$view, &$output, &$cache) {
  if (RemoteNodeController::$remoteDatabase) {
    // Restore the active database connection.
    RemoteNodeController::restoreDatabase();
  }
}
